Module classes

Module classes 

Synthetic standard-library class recognition shared by frontends and codegen.

Enums

StdlibClass
Standard-library class modeled with dedicated runtime support instead of user-defined struct emission.

Constants

MATCH_CLASS_NAME
Reserved synthetic class name for a RegExp match result value.
MATCH_GROUPS_CLASS_NAME
Reserved synthetic class name for matchResult.groups named-group access.
TYPED_ARRAY_CLASS_NAMES
The JavaScript typed-array view constructor names, in a stable order.

Functions

is_typed_array_class_name
Return whether a class name is one of the JavaScript typed-array views.
typescript_stdlib_class
Return the stdlib class modeled by a TypeScript class type name.