#[non_exhaustive]pub enum FieldRule {
TsLength,
TsConstructor,
TsSort,
}Expand description
Field read whose semantics come from the standard library rather than a user-defined type shape.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TsLength
JavaScript .length on string/array-shaped receivers.
TsConstructor
JavaScript .constructor, which Smelt erases to a null value.
TsSort
JavaScript .sort read as a bound array method on erased receivers.