host_object_by_class

Function host_object_by_class 

pub fn host_object_by_class(class_name: &str) -> Option<&'static HostObject>
Look up the host-object identity for a JavaScript constructor name.

Returns None for names that are not modeled host objects so callers can fall through to their existing user-class / stdlib dispatch.