#[non_exhaustive]pub struct CallRecognition {
pub receiver: Option<&'static str>,
pub member: &'static str,
pub rule: RuleId,
}Expand description
Exact syntactic call name that can be recognized without semantic inspection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.receiver: Option<&'static str>Static namespace receiver, or None for a global free function.
member: &'static strFunction or static method name.
rule: RuleIdShared rule selected by this exact source spelling.