String runtime helpers.
These back JavaScript global string functions that need more than a direct Rust std method call.
Constants
- ENCODE_
URI - Percent-encodes a string; backs
encodeURI(value)(Rvalue::UriEncode).
String runtime helpers.
These back JavaScript global string functions that need more than a direct Rust std method call.
encodeURI(value) (Rvalue::UriEncode).