Synthetic standard-library class recognition shared by frontends and codegen.
Enums
- Stdlib
Class - Standard-library class modeled with dedicated runtime support instead of user-defined struct emission.
Constants
- MATCH_
CLASS_ NAME - Reserved synthetic class name for a
RegExpmatch result value. - MATCH_
GROUPS_ CLASS_ NAME - Reserved synthetic class name for
matchResult.groupsnamed-group access. - TYPED_
ARRAY_ CLASS_ NAMES - The JavaScript typed-array view constructor names, in a stable order.
Functions
- is_
typed_ array_ class_ name - Return whether a class name is one of the JavaScript typed-array views.
- typescript_
stdlib_ class - Return the stdlib class modeled by a TypeScript class type name.